relaton-py
==========

.. image:: https://codecov.io/gh/relaton/relaton-py/branch/master/graph/badge.svg?token=TLQzB7fg5U
   :target: https://codecov.io/gh/relaton/relaton-py
      
Utilities and data models for working with Relaton bibliographic items.

For latest documentation, see https://relaton-py.readthedocs.io/.
